@@ -21,11 +21,7 @@ class Activity():
         self.orientation = ''
         self.verb = ''
 
-        self.properties = []
-        for property in self.home.properties:
-            self.properties.append(Property(
-                self.home, self.post, self, property
-            ))
+        self.define_properties()
 
         self.properties[0].value = (
             self.post.short_date + " SYR " + self.orientation + ' ' +
@@ -37,3 +33,15 @@ class Activity():
             self.fields.append(property.value)
 
         home.csvwrite(self.fields)
+
+    def define_properties(self):
+        self.properties = []
+        self.restart = False
+        for property in self.home.properties:
+            if self.restart:
+                self.restart = False
+                self.define_properties()
+                break
+            self.properties.append(Property(
+                self.home, self.post, self, property
+            ))
