@@ -9,7 +9,7 @@ from .post import Post
 class Home():
     def __init__(self):
         print(
-            '\nWelcome to SIGACTor, currently available '
+            '\nWelcome to SIGACTor 0.1.11dev, currently available '
             'for the Syria team and reading posts from the '
             "Syrian Observatory for Human Rights' Facebook Page."
         )
